==> eventbridgestepfunctions-1.172.0-sources.jar: software/amazon/awsconstructs/services/eventbridgestepfunctions/EventbridgeToStepfunctions.java <==
package software.amazon.awsconstructs.services.eventbridgestepfunctions;

@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-18T19:55:15.871Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.eventbridgestepfunctions.$Module.class, fqn = "@aws-solutions-constructs/aws-eventbridge-stepfunctions.EventbridgeToStepfunctions")
public class EventbridgeToStepfunctions extends software.amazon.awscdk.core.Construct {

    protected EventbridgeToStepfunctions(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected EventbridgeToStepfunctions(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public EventbridgeToStepfunctions(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctionsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.events.Rule getEventsRule() {
        return software.amazon.jsii.Kernel.get(this, "eventsRule", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.events.Rule.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StateMachine getStateMachine() {
        return software.amazon.jsii.Kernel.get(this, "stateMachine", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StateMachine.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.ILogGroup getStateMachineLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "stateMachineLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.ILogGroup.class));
    }

    public @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm> getCloudwatchAlarms() {
        return java.util.Optional.ofNullable((java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm>)(software.amazon.jsii.Kernel.get(this, "cloudwatchAlarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.Alarm.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.events.IEventBus getEventBus() {
        return software.amazon.jsii.Kernel.get(this, "eventBus", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.events.IEventBus.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctions}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctions> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctionsProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctionsProps.Builder();
        }

        /**
         * User provided eventRuleProps to override the defaults.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param eventRuleProps User provided eventRuleProps to override the defaults. This parameter is required.
         */
        public Builder eventRuleProps(final software.amazon.awscdk.services.events.RuleProps eventRuleProps) {
            this.props.eventRuleProps(eventRuleProps);
            return this;
        }

        /**
         * User provided StateMachineProps to override the defaults.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param stateMachineProps User provided StateMachineProps to override the defaults. This parameter is required.
         */
        public Builder stateMachineProps(final software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps) {
            this.props.stateMachineProps(stateMachineProps);
            return this;
        }

        /**
         * Whether to create recommended CloudWatch alarms.
         * <p>
         * Default: - Alarms are created
         * <p>
         * @return {@code this}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms. This parameter is required.
         */
        public Builder createCloudWatchAlarms(final java.lang.Boolean createCloudWatchAlarms) {
            this.props.createCloudWatchAlarms(createCloudWatchAlarms);
            return this;
        }

        /**
         * A new custom EventBus is created with provided props.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param eventBusProps A new custom EventBus is created with provided props. This parameter is required.
         */
        public Builder eventBusProps(final software.amazon.awscdk.services.events.EventBusProps eventBusProps) {
            this.props.eventBusProps(eventBusProps);
            return this;
        }

        /**
         * Existing instance of a custom EventBus.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingEventBusInterface Existing instance of a custom EventBus. This parameter is required.
         */
        public Builder existingEventBusInterface(final software.amazon.awscdk.services.events.IEventBus existingEventBusInterface) {
            this.props.existingEventBusInterface(existingEventBusInterface);
            return this;
        }

        /**
         * User provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctions}.
         */
        @Override
        public software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctions build() {
            return new software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctions(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> eventbridgestepfunctions-2.29.0-sources.jar: software/amazon/awsconstructs/services/eventbridgestepfunctions/EventbridgeToStepfunctions.java <==
package software.amazon.awsconstructs.services.eventbridgestepfunctions;

@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-04T22:45:46.424Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.eventbridgestepfunctions.$Module.class, fqn = "@aws-solutions-constructs/aws-eventbridge-stepfunctions.EventbridgeToStepfunctions")
public class EventbridgeToStepfunctions extends software.constructs.Construct {

    protected EventbridgeToStepfunctions(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected EventbridgeToStepfunctions(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public EventbridgeToStepfunctions(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctionsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.events.Rule getEventsRule() {
        return software.amazon.jsii.Kernel.get(this, "eventsRule", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.events.Rule.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StateMachine getStateMachine() {
        return software.amazon.jsii.Kernel.get(this, "stateMachine", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StateMachine.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.ILogGroup getStateMachineLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "stateMachineLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.ILogGroup.class));
    }

    public @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm> getCloudwatchAlarms() {
        return java.util.Optional.ofNullable((java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm>)(software.amazon.jsii.Kernel.get(this, "cloudwatchAlarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.Alarm.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.events.IEventBus getEventBus() {
        return software.amazon.jsii.Kernel.get(this, "eventBus", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.events.IEventBus.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctions}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctions> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctionsProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctionsProps.Builder();
        }

        /**
         * User provided eventRuleProps to override the defaults.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param eventRuleProps User provided eventRuleProps to override the defaults. This parameter is required.
         */
        public Builder eventRuleProps(final software.amazon.awscdk.services.events.RuleProps eventRuleProps) {
            this.props.eventRuleProps(eventRuleProps);
            return this;
        }

        /**
         * User provided StateMachineProps to override the defaults.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param stateMachineProps User provided StateMachineProps to override the defaults. This parameter is required.
         */
        public Builder stateMachineProps(final software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps) {
            this.props.stateMachineProps(stateMachineProps);
            return this;
        }

        /**
         * Whether to create recommended CloudWatch alarms.
         * <p>
         * Default: - Alarms are created
         * <p>
         * @return {@code this}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms. This parameter is required.
         */
        public Builder createCloudWatchAlarms(final java.lang.Boolean createCloudWatchAlarms) {
            this.props.createCloudWatchAlarms(createCloudWatchAlarms);
            return this;
        }

        /**
         * A new custom EventBus is created with provided props.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param eventBusProps A new custom EventBus is created with provided props. This parameter is required.
         */
        public Builder eventBusProps(final software.amazon.awscdk.services.events.EventBusProps eventBusProps) {
            this.props.eventBusProps(eventBusProps);
            return this;
        }

        /**
         * Existing instance of a custom EventBus.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingEventBusInterface Existing instance of a custom EventBus. This parameter is required.
         */
        public Builder existingEventBusInterface(final software.amazon.awscdk.services.events.IEventBus existingEventBusInterface) {
            this.props.existingEventBusInterface(existingEventBusInterface);
            return this;
        }

        /**
         * User provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctions}.
         */
        @Override
        public software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctions build() {
            return new software.amazon.awsconstructs.services.eventbridgestepfunctions.EventbridgeToStepfunctions(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
